@@ -3,7 +3,7 @@ import requests
 from assembla.lib import AssemblaObject, assembla_filter
 import settings
 
-__VERSION__ = '2.1.0'
+__VERSION__ = '2.1.1'
 
 class API(object):
     cache_responses = False
@@ -104,9 +104,10 @@ class API(object):
             return []
         else:  # Most likely a 404 Not Found
             raise Exception(
-                'Code {0} returned from `{1}`.'.format(
+                'Code {0} returned from `{1}`. Response text: "{2}".'.format(
                     response.status_code,
                     url,
+                    response.text
                 )
             )
 
