@@ -1,13 +1,12 @@
 from functools import wraps
 
+
 class AssemblaObject(object):
     """
     Proxies getitem calls (eg: `instance['id']`) to a dictionary `instance.data['id']`.
     """
-
-    def __init__(self, data, api):
+    def __init__(self, data):
         self.data = data
-        self.api = api
 
     def __getitem__(self, key):
         return self.data[key]
@@ -21,6 +20,7 @@ class AssemblaObject(object):
     def get(self, *args, **kwargs):
         return self.data.get(*args, **kwargs)
 
+
 def assembla_filter(func):
     """
     Filters :data for the objects in it which possess attributes equal in
@@ -38,10 +38,10 @@ def assembla_filter(func):
             return filter(
                 # Find the objects who have an equal number of matching attr/value
                 # combinations as `len(kwargs)`
-                lambda object: len(kwargs) == len(
+                lambda obj: len(kwargs) == len(
                     filter(
                         lambda boolean: boolean,
-                        [object.get(attr_name) == value
+                        [obj.get(attr_name) == value
                             for attr_name, value in kwargs.iteritems()]
                     )
                 ),
